# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/),
and this project adheres to [Semantic Versioning](http://semver.org/).

## Unreleased


## v0.5.0 - 2024-11-05

- Added `--version` flag
- Added github actions
- Migrated to main python version 3.13
- Added badges to README.md


## v0.4.0 - 2024-11-01

- Added ephemeral output


## v0.3.0 - 2024-11-01

- Added fuzzy search for matching items


## v0.2.0 - 2024-11-01

- Added README, LICENSE, CHANGELOG
- Cleaned up interface a little
- Added help and docstrings
- Added Makefile for convenience
- Added ruff, mypy quality checks


## v0.1.0 - 2024-10-31

- Initial release of ksec
